@@ -15,7 +15,7 @@ class ManageFiles():
     # and the location where the file will be stored in
     def download_file(self, file_key, base_path):
         # Setting the url for the file by combining FMS API base url and the file key
-        url = f"http://{self.fms_url}/{file_key}"
+        url = f"{self.fms_url}/{file_key}"
         # Sending get request to FMS API 
         with requests.get(url, stream=True) as response:
             # Retrun error if happened during HTTP request
@@ -40,7 +40,7 @@ class ManageFiles():
     # file group and the name creater of the file
     def upload_file(self, file_key, file_name, file_extention, base_path, group = None, created_by = None):
         # Setting the url for the file by combining FMS API base url and the file key
-        url = f"http://{self.fms_url}/{file_key}"
+        url = f"{self.fms_url}/{file_key}"
         # Setting the location of the file to be uploaded
         file_location = os.path.join(base_path,f"{file_name}.{file_extention}")
         # Setting the header of the post request, file extension must be sent in the headers as same as the original extesion of the file
@@ -52,10 +52,13 @@ class ManageFiles():
         with open(file_location, 'rb') as file:
             # Sending the file using post request, parametrs: file (opened targeted file) ,
             # headers: preset headers, stream = True for stream upload
-            with file_request.post(url, file, headers=headers, stream=True) as req:
-                # Retrun error if happened during HTTP request
-                if req.raise_for_status():
-                    print(req)
+            try: 
+                post_request = file_request.post(url, file, headers=headers, stream=True)
+                print(post_request)
+                    
+            except: 
+                print(post_request)
+
         # Closing post request after finishing upload
         file_request.close()
         # Return success message
